Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EncodeDecoder ¶
type ExposeBufioReader ¶
type RC4Tube ¶
type RC4Tube struct {
io.ReadWriteCloser
*bufio.Reader
*gob.Encoder
*gob.Decoder
// contains filtered or unexported fields
}
RC4Tube is a tube whose traffic is symmetrically encrypted with RC4
func NewRC4Tube ¶
func (*RC4Tube) ExposeBufioReader ¶
type Tube ¶
Tube is a wrapper around a net.Conn with a buffered reader and associated gob encoder and decoder
func (*Tube) Close ¶
Due to the complex concurrent ways in which tubes are used, a Tube must behave properly when Close is called after Hijack, or repeatedly.
func (*Tube) ExposeBufioReader ¶
type TubedConn ¶
type TubedConn interface {
EncodeDecoder
ExposeBufioReader
io.Reader
io.Writer
io.Closer
Hijack() (io.ReadWriteCloser, *bufio.Reader)
}
Click to show internal directories.
Click to hide internal directories.